@@ -1,10 +1,13 @@
 metaFun <- function(type, name, fun, labels = NULL) {
-    if (!is.character(type) || length(type) != 1)
+    if (!is.character(type) || length(type) != 1) {
         stop("type must be a character string of length 1")
-    if (!is.character(name) || length(name) != 1)
+    }
+    if (!is.character(name) || length(name) != 1) {
         stop("name must be a character string of length 1")
-    if (!is.function(fun))
+    }
+    if (!is.function(fun)) {
         stop("fun should be, well, a function ...")
+    }
 
     ## check for renaming: x=y (x is a function of y)
     if (grepl(".+=.+", name)) {
@@ -27,22 +30,19 @@ metaFun <- function(type, name, fun, labels = NULL) {
     )
 }
 
-print.inzmetafun <- function(x, ...) {
-    cat(sprintf("%s: a %s variable", x$name, x$type))
-    if (rename(x))
-        cat(sprintf(" based on %s", x$rename))
-    cat("\n")
-}
-
 ## Accessors:
 getname <- function(x, original = TRUE) {
-    name <- if (original && rename(x))
+    name <- if (original && rename(x)) {
         x$rename
-    else
+    } else {
         x$name
+    }
 }
+
 rename <- function(x) !is.null(x$rename)
+
 getrename <- function(x) x$rename
+
 gettype <- function(x, abbr = FALSE) {
     if (abbr) {
         return(
